==> library1.4.1.tar.bz2: library/logs/statistic_sm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn27-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_adm.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;

?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="50%">
<tr>
 <td align="right" width="18"><a href="statistic.php" title="<?php echo $TEXT['book-stat-big-tit']; ?>" ><img alt="<?php echo $TEXT['book-stat-big']; ?>" src='../skins/<?php echo $result2['skin']; ?>/plus.png' /></a></td>
 <td class="informssilka"><?php echo $TEXT['book-stat-big']; ?></td>
</tr>
</table>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="50%">
 <thead>
  <tr class='tableheadercat'>
   <td><?php echo $TEXT['book-name']; ?></td>
   <td><?php echo $TEXT['book-obr-stat']; ?></td>
  </tr>
 </thead>
 <tbody id="tab">
<?php
     $query = "SELECT 
     tbl_statistik.book_id,
     COUNT(tbl_statistik.book_id) AS stat_book_id,
     tbl_book.book_id,
     tbl_book.book_name
     FROM tbl_statistik
     JOIN tbl_book ON tbl_statistik.book_id=tbl_book.book_id
     GROUP BY tbl_statistik.book_id
     ORDER BY tbl_book.book_name LIMIT $lim_ogr ";
     $result = mysqli_query($dbcnx,$query);
     if(!$result) {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result);
        if($result_rows >0)
         {
          while($result_stat = mysqli_fetch_array($result))
           {
           $book_name = "<a href=statistic.php?book_id=".$result_stat['book_id']." title='".$TEXT['aut-viewtit']."'>".rep_back($result_stat['book_name'])."</a>";

           ?>
           <tr>
              <td class="informcntr"><?php echo $book_name; ?></td>
              <td><?php echo $result_stat['stat_book_id']; ?></td>
           </tr>
           <?php
               }
         }
?>
</tbody>
</table>
<?php
       $query_count = mysqli_query($dbcnx,"SELECT DISTINCT(book_id) AS c_book_id FROM tbl_statistik");
          $coun_rows = mysqli_num_rows($query_count);
              $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='statistic_sm.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='statistic_sm.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=statistic_sm.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=statistic_sm.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/logs/statistic_sm.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['menu-btn27-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom_adm.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;

?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="50%">
<tr>
 <td align="right" width="18"><a href="statistic.php" title="<?php echo $TEXT['book-stat-big-tit']; ?>" ><img alt="<?php echo $TEXT['book-stat-big']; ?>" src='../skins/<?php echo $result2['skin']; ?>/plus.png' /></a></td>
 <td class="informssilka"><?php echo $TEXT['book-stat-big']; ?></td>
</tr>
</table>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="50%">
 <thead>
  <tr class="tableheadercat">
   <td><?php echo $TEXT['book-name']; ?></td>
   <td><?php echo $TEXT['book-obr-stat']; ?></td>
  </tr>
 </thead>
 <tbody id="tab">
<?php
     $query = "SELECT 
     ANY_VALUE(tbl_statistik.book_id),
     COUNT(tbl_statistik.book_id) AS stat_book_id,
     ANY_VALUE(tbl_book.book_id) AS book_id,
     ANY_VALUE(tbl_book.book_name) AS book_name
     FROM tbl_statistik
     JOIN tbl_book ON tbl_statistik.book_id=tbl_book.book_id
     GROUP BY tbl_statistik.book_id
     ORDER BY COUNT(tbl_statistik.book_id) DESC, tbl_book.book_name ASC LIMIT $lim_ogr ";
     $result = mysqli_query($dbcnx,$query);
     if(!$result) {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
       $result_rows = mysqli_num_rows($result);
        if($result_rows >0)
         {
          while($result_stat = mysqli_fetch_array($result))
           {
           $book_name = "<a href='statistic.php?book_id=".$result_stat['book_id']."' title='".$TEXT['aut-viewtit']."'>".rep_back($result_stat['book_name'])."</a>";

           ?>
           <tr>
              <td class="informcntr"><?php echo $book_name; ?></td>
              <td><?php echo $result_stat['stat_book_id']; ?></td>
           </tr>
           <?php
               }
         }
?>
</tbody>
</table>
<?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(DISTINCT book_id) AS c_book_id FROM tbl_statistik");
          $coun_rows = mysqli_fetch_array($query_count);
              $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='statistic_sm.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='statistic_sm.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=statistic_sm.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=statistic_sm.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "../utils/bottom_adm.php";
?>
